==> haskell-ansi-terminal-types-0.11.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-LVsK0snOjnPBDLo5QCJ5s7
key:                  ansi-terminal-types-0.11.5-LVsK0snOjnPBDLo5QCJ5s7
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  3287e008f81ffd8d4e278a1c008ed3fc
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-LVsK0snOjnPBDLo5QCJ5s7
depends:              base-4.16.4.0 colour-2.3.6-6mRDx5VsJCs2S1QovYYv5V
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-types-0.11.5-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-94tBGyEfSQUHisdUb8P9op
key:                  ansi-terminal-types-0.11.5-94tBGyEfSQUHisdUb8P9op
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  cc9230049866cbcbe90cc4f735e7b043
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-94tBGyEfSQUHisdUb8P9op
depends:              base-4.17.2.1 colour-2.3.6-5Hdg5NZuPkoIAWxSFkdA0e
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
